@@ -3,7 +3,7 @@ __version__ = "0.1.0"
 try:
     import main
 except ModuleNotFoundError:
-    from search_that_hasg import main
+    from search_that_hash import main
 
 if __name__ == "__main__":
-    main.main()
\ No newline at end of file
+    main.main()
